1.0 (2021-04-01)
================

- more NIR/MIR average models added (RRP89, G21_MWAvg)
- dust grain models added (WD01, D03, J13, ZDA04)

0.9 (2020-06-05)
================

- NIR/MIR average models added
  (RL85_MWGC, I05_MWAvg, CT06_MWLoc, CT06_MWGC, F11_MWGC)
- updates to be remove astropy 4.0 deprecated modeling features
- Documentation updates
- Many tests consolidated
- Bugfixes

0.8 (2019-08-20)
================

- VCG04, GCC09, FM19 models added

0.7 (2019-02-11)
================

- GCC09_MWAvg, O94, F04, M14 models added
- AxAvtoExv helper model added
- significant updates to the documentation
- extinction versus attenuation documentation added
- models reorganized into 3 categories (*API change*)
- made a new base class for R(V)_A, f_A dependent models (G16, expecting more)

0.6 (2017-11-15)
================

- minor updates to release version, notes

0.5 (2017-11-15)
================

- initial release
